<?php

namespace EventPortal\Domain\EventDelegate\Handlers;

use Closure;
use EventPortal\Domain\Delegate\Models\DelegateFormData;
use EventPortal\Domain\Form\Payload;
use Illuminate\Support\Str;

class UpdateFormData
{
    /**
     * @return mixed
     */
    public function __invoke(Payload $payload, Closure $next)
    {
        /** @var \EventPortal\Domain\Delegate\Models\Delegate $delegate */
        $delegate = $payload->getContext('eventDelegate')->delegate;

        /** @var \EventPortal\Domain\Event\Form\Models\FormStep $step */
        $step = $payload->getContext('formStep');

        DelegateFormData::forDelegate($delegate)->forStep($step)->delete();

        $step->sections->each(static function ($section) use ($delegate, $step, $payload): void {
            $section->questions->each(static function ($question) use ($delegate, $step, $payload): void {
                $value = $payload->getInput(Str::slug($question->question, '_'));

                if ($value === null) {
                    return;
                }

                if (ctype_digit($value)) {
                    $value = (int) $value;
                }

                if (is_array($value)) {
                    $value = json_encode($value);
                }

                DelegateFormData::create([
                    'delegate_id' => $delegate->id,
                    'form_step_id' => $step->id,
                    'question_id' => $question->id,
                    'value' => $value,
                ]);
            });
        });

        return $next($payload);
    }
}
